{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/deeptools:3.1.1",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 15000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "plotCoverage"
            ],
            "arguments": [
                {
                    "valueFrom": "${\n  if ( inputs.is_paired_end ){\n     return null;\n  }\n  else {\n    return \"--extendReads\";\n  }\n}\n",
                    "position": 1
                },
                {
                    "valueFrom": "${\n  if ( inputs.is_paired_end ){\n     return null;\n  }\n  else {\n    return inputs.fragment_size;\n  }\n}\n",
                    "position": 2
                },
                {
                    "valueFrom": "$(inputs.sample_id)",
                    "prefix": "--labels",
                    "position": 10
                },
                {
                    "valueFrom": "$(inputs.sample_id + \".plot_cov.png\")",
                    "prefix": "--plotFile",
                    "position": 10
                },
                {
                    "valueFrom": "$(inputs.sample_id + \".plot_cov.tsv\")",
                    "prefix": "--outRawCounts",
                    "position": 10
                }
            ],
            "inputs": [
                {
                    "doc": "must be indexed",
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "inputBinding": {
                        "position": 100,
                        "prefix": "--bamfiles"
                    },
                    "id": "#deeptools_plotCoverage.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#deeptools_plotCoverage.cwl/fragment_size"
                },
                {
                    "doc": "if paired end, reads are extended",
                    "type": "boolean",
                    "default": true,
                    "id": "#deeptools_plotCoverage.cwl/is_paired_end"
                },
                {
                    "type": "string",
                    "id": "#deeptools_plotCoverage.cwl/sample_id"
                }
            ],
            "id": "#deeptools_plotCoverage.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_id + \".plot_cov.png\")"
                    },
                    "id": "#deeptools_plotCoverage.cwl/qc_plot_coverage_plot"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_id + \".plot_cov.tsv\")"
                    },
                    "id": "#deeptools_plotCoverage.cwl/qc_plot_coverage_tsv"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/deeptools:3.1.1",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 15000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "plotFingerprint"
            ],
            "arguments": [
                {
                    "valueFrom": "${\n  if ( inputs.is_paired_end ){\n     return null;\n  }\n  else {\n    return \"--extendReads\";\n  }\n}\n",
                    "position": 1
                },
                {
                    "valueFrom": "${\n  if ( inputs.is_paired_end ){\n     return null;\n  }\n  else {\n    return inputs.fragment_size;\n  }\n}\n",
                    "position": 2
                },
                {
                    "valueFrom": "$(inputs.sample_id)",
                    "prefix": "--labels",
                    "position": 10
                },
                {
                    "valueFrom": "$(inputs.sample_id + \".plot_fingerp.png\")",
                    "prefix": "--plotFile",
                    "position": 10
                },
                {
                    "valueFrom": "$(inputs.sample_id + \".plot_fingerp.tsv\")",
                    "prefix": "--outRawCounts",
                    "position": 10
                }
            ],
            "stderr": "$( inputs.sample_id + \".plot_fingerp.stderr\")",
            "inputs": [
                {
                    "doc": "must be indexed",
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "inputBinding": {
                        "position": 100,
                        "prefix": "--bamfiles"
                    },
                    "id": "#deeptools_plotFingerprint.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#deeptools_plotFingerprint.cwl/fragment_size"
                },
                {
                    "doc": "if paired end, reads are extended",
                    "type": "boolean",
                    "default": true,
                    "id": "#deeptools_plotFingerprint.cwl/is_paired_end"
                },
                {
                    "type": "string",
                    "id": "#deeptools_plotFingerprint.cwl/sample_id"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sample_id + \".plot_fingerp.png\")"
                    },
                    "id": "#deeptools_plotFingerprint.cwl/qc_plot_fingerprint_plot"
                },
                {
                    "type": "File",
                    "id": "#deeptools_plotFingerprint.cwl/qc_plot_fingerprint_stderr",
                    "outputBinding": {
                        "glob": "$( inputs.sample_id + \".plot_fingerp.stderr\")"
                    }
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sample_id + \".plot_fingerp.tsv\")"
                    },
                    "id": "#deeptools_plotFingerprint.cwl/qc_plot_fingerprint_tsv"
                }
            ],
            "successCodes": [
                0,
                1,
                2
            ],
            "temporaryFailCodes": [],
            "permanentFailCodes": [],
            "id": "#deeptools_plotFingerprint.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "coresMin": 1,
                    "ramMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#frag_size_decision_maker.cwl/cc_fragment_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#frag_size_decision_maker.cwl/user_def_fragment_size"
                }
            ],
            "expression": "${\n    var fragment_size = inputs.user_def_fragment_size;\n    if( fragment_size == null ){\n        fragment_size = inputs.cc_fragment_size;\n    }\n    return { \"fragment_size\": fragment_size }\n}\n",
            "outputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#frag_size_decision_maker.cwl/fragment_size"
                }
            ],
            "id": "#frag_size_decision_maker.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/phantompeakqualtools:1.2",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 20000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "Rscript",
                "--verbose",
                "--max-ppsize=500000",
                "/usr/bin/phantompeakqualtools-1.2/run_spp.R"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "-tmpdir=",
                    "separate": false,
                    "position": 10
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-odir=",
                    "separate": false,
                    "position": 10
                },
                {
                    "valueFrom": "$(inputs.bam.nameroot + \".crosscor.pdf\")",
                    "prefix": "-savp=",
                    "separate": false,
                    "position": 100
                },
                {
                    "valueFrom": "$(inputs.bam.nameroot + \".spp.out\")",
                    "prefix": "-out=",
                    "separate": false,
                    "position": 100
                }
            ],
            "stderr": "$(inputs.bam.nameroot + \".phantompeakqualtools_stderr\")",
            "stdout": "$(inputs.bam.nameroot + \".phantompeakqualtools_stdout\")",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c=",
                        "separate": false,
                        "position": 10
                    },
                    "id": "#phantompeakqualtools.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "outputBinding": {
                        "glob": "*.spp.out",
                        "loadContents": true,
                        "outputEval": "$(parseInt(self[0].contents.split('\\t')[2]))"
                    },
                    "id": "#phantompeakqualtools.cwl/qc_crosscorr_fragment_size"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.pdf"
                    },
                    "id": "#phantompeakqualtools.cwl/qc_crosscorr_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.spp.out"
                    },
                    "id": "#phantompeakqualtools.cwl/qc_crosscorr_summary"
                },
                {
                    "type": "File",
                    "id": "#phantompeakqualtools.cwl/qc_phantompeakqualtools_stderr",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot + \".phantompeakqualtools_stderr\")"
                    }
                },
                {
                    "type": "File",
                    "id": "#phantompeakqualtools.cwl/qc_phantompeakqualtools_stdout",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot + \".phantompeakqualtools_stdout\")"
                    }
                }
            ],
            "successCodes": [
                0,
                1,
                2
            ],
            "temporaryFailCodes": [],
            "permanentFailCodes": [],
            "id": "#phantompeakqualtools.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "id": "#main/bam"
                },
                {
                    "type": "boolean",
                    "id": "#main/is_paired_end"
                },
                {
                    "type": "string",
                    "id": "#main/sample_id"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/user_def_fragment_size"
                }
            ],
            "steps": [
                {
                    "doc": "If no user-defined fragment size was set,\nthe fragment size infered from cross-correlation analysis \nwill be used.\n",
                    "run": "#frag_size_decision_maker.cwl",
                    "in": [
                        {
                            "source": "#main/qc_phantompeakqualtools/qc_crosscorr_fragment_size",
                            "id": "#main/fragment_size_decision_maker/cc_fragment_size"
                        },
                        {
                            "source": "#main/user_def_fragment_size",
                            "id": "#main/fragment_size_decision_maker/user_def_fragment_size"
                        }
                    ],
                    "out": [
                        "#main/fragment_size_decision_maker/fragment_size"
                    ],
                    "id": "#main/fragment_size_decision_maker"
                },
                {
                    "run": "#phantompeakqualtools.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/qc_phantompeakqualtools/bam"
                        }
                    ],
                    "out": [
                        "#main/qc_phantompeakqualtools/qc_crosscorr_summary",
                        "#main/qc_phantompeakqualtools/qc_crosscorr_plot",
                        "#main/qc_phantompeakqualtools/qc_crosscorr_fragment_size",
                        "#main/qc_phantompeakqualtools/qc_phantompeakqualtools_stderr",
                        "#main/qc_phantompeakqualtools/qc_phantompeakqualtools_stdout"
                    ],
                    "id": "#main/qc_phantompeakqualtools"
                },
                {
                    "doc": "deeptools plotCoverage - plots how many times a certain fraction of the \ngenome was covered (consideres the complete fragment between a reads pair).\n",
                    "run": "#deeptools_plotCoverage.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/qc_plot_coverage/bam"
                        },
                        {
                            "source": "#main/fragment_size_decision_maker/fragment_size",
                            "id": "#main/qc_plot_coverage/fragment_size"
                        },
                        {
                            "source": "#main/is_paired_end",
                            "id": "#main/qc_plot_coverage/is_paired_end"
                        },
                        {
                            "source": "#main/sample_id",
                            "id": "#main/qc_plot_coverage/sample_id"
                        }
                    ],
                    "out": [
                        "#main/qc_plot_coverage/qc_plot_coverage_plot",
                        "#main/qc_plot_coverage/qc_plot_coverage_tsv"
                    ],
                    "id": "#main/qc_plot_coverage"
                },
                {
                    "doc": "Applies deeptools plotFingerprint to generate meaningful plots for comparing IP and\ncontrol samples in terms of quality control. The main question which can be answered is:\nDid the antibody lead to enough enrichment that the IP can be distinguished from the control? \n",
                    "run": "#deeptools_plotFingerprint.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/qc_plot_fingerprint/bam"
                        },
                        {
                            "source": "#main/fragment_size_decision_maker/fragment_size",
                            "id": "#main/qc_plot_fingerprint/fragment_size"
                        },
                        {
                            "source": "#main/is_paired_end",
                            "id": "#main/qc_plot_fingerprint/is_paired_end"
                        },
                        {
                            "source": "#main/sample_id",
                            "id": "#main/qc_plot_fingerprint/sample_id"
                        }
                    ],
                    "out": [
                        "#main/qc_plot_fingerprint/qc_plot_fingerprint_plot",
                        "#main/qc_plot_fingerprint/qc_plot_fingerprint_tsv",
                        "#main/qc_plot_fingerprint/qc_plot_fingerprint_stderr"
                    ],
                    "id": "#main/qc_plot_fingerprint"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "outputSource": "#main/fragment_size_decision_maker/fragment_size",
                    "id": "#main/fragment_size"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc_phantompeakqualtools/qc_crosscorr_plot",
                    "id": "#main/qc_crosscorr_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc_phantompeakqualtools/qc_crosscorr_summary",
                    "id": "#main/qc_crosscorr_summary"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc_phantompeakqualtools/qc_phantompeakqualtools_stderr",
                    "id": "#main/qc_phantompeakqualtools_stderr"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc_phantompeakqualtools/qc_phantompeakqualtools_stdout",
                    "id": "#main/qc_phantompeakqualtools_stdout"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc_plot_coverage/qc_plot_coverage_plot",
                    "id": "#main/qc_plot_coverage_plot"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc_plot_coverage/qc_plot_coverage_tsv",
                    "id": "#main/qc_plot_coverage_tsv"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc_plot_fingerprint/qc_plot_fingerprint_plot",
                    "id": "#main/qc_plot_fingerprint_plot"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc_plot_fingerprint/qc_plot_fingerprint_stderr",
                    "id": "#main/qc_plot_fingerprint_stderr"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/qc_plot_fingerprint/qc_plot_fingerprint_tsv",
                    "id": "#main/qc_plot_fingerprint_tsv"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
